<a id="types-aiobotocore-devops-guru"></a>

# types-aiobotocore-devops-guru

[![PyPI - types-aiobotocore-devops-guru](https://img.shields.io/pypi/v/types-aiobotocore-devops-guru.svg?color=blue)](https://pypi.org/project/types-aiobotocore-devops-guru)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-devops-guru.svg?color=blue)](https://pypi.org/project/types-aiobotocore-devops-guru)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-devops-guru?color=blue)](https://pypistats.org/packages/types-aiobotocore-devops-guru)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.DevOpsGuru 2.4.2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.12.2](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-devops-guru docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_devops_guru/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-devops-guru](#types-aiobotocore-devops-guru)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `DevOpsGuru` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[devops-guru]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[devops-guru]'


# standalone installation
python -m pip install types-aiobotocore-devops-guru
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-devops-guru
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[devops-guru]` in your environment:

```bash
python -m pip install 'types-aiobotocore[devops-guru]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[devops-guru]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[devops-guru]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[devops-guru]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[devops-guru]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[devops-guru]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[devops-guru]` in your environment:

```bash
python -m pip install 'types-aiobotocore[devops-guru]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[devops-guru]` in your environment:

```bash
python -m pip install 'types-aiobotocore[devops-guru]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`DevOpsGuruClient` provides annotations for
`session.create_client("devops-guru")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_devops_guru import DevOpsGuruClient

session = get_session()
async with session.create_client("devops-guru") as client:
    client: DevOpsGuruClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_devops_guru.paginator` module contains type annotations for
all paginators.

```python
from aiobotocore.session import get_session

from types_aiobotocore_devops_guru import DevOpsGuruClient
from types_aiobotocore_devops_guru.paginator import (
    DescribeOrganizationResourceCollectionHealthPaginator,
    DescribeResourceCollectionHealthPaginator,
    GetCostEstimationPaginator,
    GetResourceCollectionPaginator,
    ListAnomaliesForInsightPaginator,
    ListAnomalousLogGroupsPaginator,
    ListEventsPaginator,
    ListInsightsPaginator,
    ListMonitoredResourcesPaginator,
    ListNotificationChannelsPaginator,
    ListOrganizationInsightsPaginator,
    ListRecommendationsPaginator,
    SearchInsightsPaginator,
    SearchOrganizationInsightsPaginator,
)

session = get_session()
async with session.create_client("devops-guru") as client:
    client: DevOpsGuruClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    describe_organization_resource_collection_health_paginator: DescribeOrganizationResourceCollectionHealthPaginator = client.get_paginator(
        "describe_organization_resource_collection_health"
    )
    describe_resource_collection_health_paginator: DescribeResourceCollectionHealthPaginator = (
        client.get_paginator("describe_resource_collection_health")
    )
    get_cost_estimation_paginator: GetCostEstimationPaginator = client.get_paginator(
        "get_cost_estimation"
    )
    get_resource_collection_paginator: GetResourceCollectionPaginator = client.get_paginator(
        "get_resource_collection"
    )
    list_anomalies_for_insight_paginator: ListAnomaliesForInsightPaginator = client.get_paginator(
        "list_anomalies_for_insight"
    )
    list_anomalous_log_groups_paginator: ListAnomalousLogGroupsPaginator = client.get_paginator(
        "list_anomalous_log_groups"
    )
    list_events_paginator: ListEventsPaginator = client.get_paginator("list_events")
    list_insights_paginator: ListInsightsPaginator = client.get_paginator("list_insights")
    list_monitored_resources_paginator: ListMonitoredResourcesPaginator = client.get_paginator(
        "list_monitored_resources"
    )
    list_notification_channels_paginator: ListNotificationChannelsPaginator = client.get_paginator(
        "list_notification_channels"
    )
    list_organization_insights_paginator: ListOrganizationInsightsPaginator = client.get_paginator(
        "list_organization_insights"
    )
    list_recommendations_paginator: ListRecommendationsPaginator = client.get_paginator(
        "list_recommendations"
    )
    search_insights_paginator: SearchInsightsPaginator = client.get_paginator("search_insights")
    search_organization_insights_paginator: SearchOrganizationInsightsPaginator = (
        client.get_paginator("search_organization_insights")
    )
```

<a id="literals"></a>

### Literals

`types_aiobotocore_devops_guru.literals` module contains literals extracted
from shapes that can be used in user code for type checking.

```python
from types_aiobotocore_devops_guru.literals import (
    AnomalySeverityType,
    AnomalyStatusType,
    AnomalyTypeType,
    CloudWatchMetricDataStatusCodeType,
    CloudWatchMetricsStatType,
    CostEstimationServiceResourceStateType,
    CostEstimationStatusType,
    DescribeOrganizationResourceCollectionHealthPaginatorName,
    DescribeResourceCollectionHealthPaginatorName,
    EventClassType,
    EventDataSourceType,
    EventSourceOptInStatusType,
    GetCostEstimationPaginatorName,
    GetResourceCollectionPaginatorName,
    InsightFeedbackOptionType,
    InsightSeverityType,
    InsightStatusType,
    InsightTypeType,
    ListAnomaliesForInsightPaginatorName,
    ListAnomalousLogGroupsPaginatorName,
    ListEventsPaginatorName,
    ListInsightsPaginatorName,
    ListMonitoredResourcesPaginatorName,
    ListNotificationChannelsPaginatorName,
    ListOrganizationInsightsPaginatorName,
    ListRecommendationsPaginatorName,
    LocaleType,
    LogAnomalyTypeType,
    OptInStatusType,
    OrganizationResourceCollectionTypeType,
    ResourceCollectionTypeType,
    ResourcePermissionType,
    ResourceTypeFilterType,
    SearchInsightsPaginatorName,
    SearchOrganizationInsightsPaginatorName,
    ServiceNameType,
    UpdateResourceCollectionActionType,
    DevOpsGuruServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AnomalySeverityType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_devops_guru.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_devops_guru.type_defs import (
    AccountInsightHealthTypeDef,
    ResponseMetadataTypeDef,
    AmazonCodeGuruProfilerIntegrationTypeDef,
    AnomalyReportedTimeRangeTypeDef,
    AnomalyResourceTypeDef,
    AnomalySourceMetadataTypeDef,
    AnomalyTimeRangeTypeDef,
    CloudFormationCollectionFilterTypeDef,
    CloudFormationCollectionTypeDef,
    CloudFormationCostEstimationResourceCollectionFilterTypeDef,
    InsightHealthTypeDef,
    TimestampMetricValuePairTypeDef,
    CloudWatchMetricsDimensionTypeDef,
    TagCostEstimationResourceCollectionFilterTypeDef,
    CostEstimationTimeRangeTypeDef,
    DeleteInsightRequestRequestTypeDef,
    DescribeAccountOverviewRequestRequestTypeDef,
    DescribeAnomalyRequestRequestTypeDef,
    DescribeFeedbackRequestRequestTypeDef,
    InsightFeedbackTypeDef,
    DescribeInsightRequestRequestTypeDef,
    DescribeOrganizationHealthRequestRequestTypeDef,
    DescribeOrganizationOverviewRequestRequestTypeDef,
    PaginatorConfigTypeDef,
    DescribeOrganizationResourceCollectionHealthRequestRequestTypeDef,
    DescribeResourceCollectionHealthRequestRequestTypeDef,
    EndTimeRangeTypeDef,
    EventResourceTypeDef,
    EventTimeRangeTypeDef,
    GetCostEstimationRequestRequestTypeDef,
    ServiceResourceCostTypeDef,
    GetResourceCollectionRequestRequestTypeDef,
    InsightTimeRangeTypeDef,
    StartTimeRangeTypeDef,
    ListAnomalousLogGroupsRequestRequestTypeDef,
    ListInsightsOngoingStatusFilterTypeDef,
    ListMonitoredResourcesFiltersTypeDef,
    MonitoredResourceIdentifierTypeDef,
    ListNotificationChannelsRequestRequestTypeDef,
    ListRecommendationsRequestRequestTypeDef,
    LogAnomalyClassTypeDef,
    LogsAnomalyDetectionIntegrationConfigTypeDef,
    LogsAnomalyDetectionIntegrationTypeDef,
    SnsChannelConfigTypeDef,
    OpsCenterIntegrationConfigTypeDef,
    OpsCenterIntegrationTypeDef,
    PerformanceInsightsMetricDimensionGroupTypeDef,
    PerformanceInsightsStatTypeDef,
    PerformanceInsightsReferenceScalarTypeDef,
    PredictionTimeRangeTypeDef,
    ServiceCollectionTypeDef,
    RecommendationRelatedAnomalyResourceTypeDef,
    RecommendationRelatedCloudWatchMetricsSourceDetailTypeDef,
    RecommendationRelatedEventResourceTypeDef,
    RemoveNotificationChannelRequestRequestTypeDef,
    TagCollectionFilterTypeDef,
    TagCollectionTypeDef,
    ServiceInsightHealthTypeDef,
    UpdateCloudFormationCollectionFilterTypeDef,
    UpdateTagCollectionFilterTypeDef,
    AccountHealthTypeDef,
    AddNotificationChannelResponseTypeDef,
    DescribeAccountHealthResponseTypeDef,
    DescribeAccountOverviewResponseTypeDef,
    DescribeOrganizationHealthResponseTypeDef,
    DescribeOrganizationOverviewResponseTypeDef,
    EventSourcesConfigTypeDef,
    CloudFormationHealthTypeDef,
    TagHealthTypeDef,
    CloudWatchMetricsDataSummaryTypeDef,
    CostEstimationResourceCollectionFilterTypeDef,
    DescribeFeedbackResponseTypeDef,
    PutFeedbackRequestRequestTypeDef,
    DescribeOrganizationResourceCollectionHealthRequestDescribeOrganizationResourceCollectionHealthPaginateTypeDef,
    DescribeResourceCollectionHealthRequestDescribeResourceCollectionHealthPaginateTypeDef,
    GetCostEstimationRequestGetCostEstimationPaginateTypeDef,
    GetResourceCollectionRequestGetResourceCollectionPaginateTypeDef,
    ListAnomalousLogGroupsRequestListAnomalousLogGroupsPaginateTypeDef,
    ListNotificationChannelsRequestListNotificationChannelsPaginateTypeDef,
    ListRecommendationsRequestListRecommendationsPaginateTypeDef,
    ListInsightsClosedStatusFilterTypeDef,
    ListAnomaliesForInsightRequestListAnomaliesForInsightPaginateTypeDef,
    ListAnomaliesForInsightRequestRequestTypeDef,
    ListInsightsAnyStatusFilterTypeDef,
    ListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef,
    ListMonitoredResourcesRequestRequestTypeDef,
    ListMonitoredResourcesResponseTypeDef,
    LogAnomalyShowcaseTypeDef,
    NotificationChannelConfigTypeDef,
    UpdateServiceIntegrationConfigTypeDef,
    ServiceIntegrationConfigTypeDef,
    PerformanceInsightsMetricQueryTypeDef,
    RecommendationRelatedAnomalySourceDetailTypeDef,
    RecommendationRelatedEventTypeDef,
    ResourceCollectionFilterTypeDef,
    ResourceCollectionTypeDef,
    ServiceHealthTypeDef,
    UpdateResourceCollectionFilterTypeDef,
    DescribeEventSourcesConfigResponseTypeDef,
    UpdateEventSourcesConfigRequestRequestTypeDef,
    CloudWatchMetricsDetailTypeDef,
    GetCostEstimationResponseTypeDef,
    StartCostEstimationRequestRequestTypeDef,
    ListInsightsStatusFilterTypeDef,
    AnomalousLogGroupTypeDef,
    AddNotificationChannelRequestRequestTypeDef,
    NotificationChannelTypeDef,
    UpdateServiceIntegrationRequestRequestTypeDef,
    DescribeServiceIntegrationResponseTypeDef,
    PerformanceInsightsReferenceMetricTypeDef,
    RecommendationRelatedAnomalyTypeDef,
    GetResourceCollectionResponseTypeDef,
    EventTypeDef,
    ListEventsFiltersTypeDef,
    ProactiveInsightSummaryTypeDef,
    ProactiveInsightTypeDef,
    ProactiveOrganizationInsightSummaryTypeDef,
    ReactiveInsightSummaryTypeDef,
    ReactiveInsightTypeDef,
    ReactiveOrganizationInsightSummaryTypeDef,
    SearchInsightsFiltersTypeDef,
    SearchOrganizationInsightsFiltersTypeDef,
    DescribeOrganizationResourceCollectionHealthResponseTypeDef,
    DescribeResourceCollectionHealthResponseTypeDef,
    UpdateResourceCollectionRequestRequestTypeDef,
    ListInsightsRequestListInsightsPaginateTypeDef,
    ListInsightsRequestRequestTypeDef,
    ListOrganizationInsightsRequestListOrganizationInsightsPaginateTypeDef,
    ListOrganizationInsightsRequestRequestTypeDef,
    ListAnomalousLogGroupsResponseTypeDef,
    ListNotificationChannelsResponseTypeDef,
    PerformanceInsightsReferenceComparisonValuesTypeDef,
    RecommendationTypeDef,
    ListEventsResponseTypeDef,
    ListEventsRequestListEventsPaginateTypeDef,
    ListEventsRequestRequestTypeDef,
    ListInsightsResponseTypeDef,
    SearchInsightsResponseTypeDef,
    SearchOrganizationInsightsResponseTypeDef,
    DescribeInsightResponseTypeDef,
    ListOrganizationInsightsResponseTypeDef,
    SearchInsightsRequestRequestTypeDef,
    SearchInsightsRequestSearchInsightsPaginateTypeDef,
    SearchOrganizationInsightsRequestRequestTypeDef,
    SearchOrganizationInsightsRequestSearchOrganizationInsightsPaginateTypeDef,
    PerformanceInsightsReferenceDataTypeDef,
    ListRecommendationsResponseTypeDef,
    PerformanceInsightsMetricsDetailTypeDef,
    AnomalySourceDetailsTypeDef,
    ProactiveAnomalySummaryTypeDef,
    ProactiveAnomalyTypeDef,
    ReactiveAnomalySummaryTypeDef,
    ReactiveAnomalyTypeDef,
    ListAnomaliesForInsightResponseTypeDef,
    DescribeAnomalyResponseTypeDef,
)


def get_structure() -> AccountInsightHealthTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-devops-guru` version is the same as related `aiobotocore`
version and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/)
format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_devops_guru/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
